@@ -108,7 +108,13 @@ class TestNewAsserts:
         try:
             Assert.is_sorted_ascending([1, 3, 2], "failure message")
         except AssertionError as e:
-            assert e.msg == "failure message"
+            assert e.msg == "2 is not before 3. failure message"
+
+    def test_is_sorted_ascending_fail_no_message(self):
+        try:
+            Assert.is_sorted_ascending([1, 3, 2])
+        except AssertionError as e:
+            assert e.msg == "2 is not before 3. "
 
     def test_is_sorted_ascending_empty(self):
         Assert.is_sorted_ascending([])
@@ -129,7 +135,13 @@ class TestNewAsserts:
         try:
             Assert.is_sorted_descending([3, 1, 2], "failure message")
         except AssertionError as e:
-            assert e.msg == "failure message"
+            assert e.msg == "1 is not before 2. failure message"
+
+    def test_is_sorted_descending_fail_no_message(self):
+        try:
+            Assert.is_sorted_descending([3, 1, 2])
+        except AssertionError as e:
+            assert e.msg == "1 is not before 2. "
 
     def test_is_sorted_descending_empty(self):
         Assert.is_sorted_descending([])
@@ -150,19 +162,42 @@ class TestNewAsserts:
         except AssertionError:
             pass
 
+    def test_raises_failure_with_message(self):
+        try:
+            Assert.raises(Exception, self._add_num, 5, 4, msg="failure message")
+        except AssertionError as e:
+            Assert.equal(e.msg, "Exception was not raised. failure message")
+
+    def test_raises_failure_without_message(self):
+        try:
+            Assert.raises(Exception, self._add_num, 5, 4,)
+        except AssertionError as e:
+            Assert.equal(e.msg, "Exception was not raised. ")
+
     def test_that_we_can_check_items_contain_something(self):
         Assert.contains("a", "bad")
         Assert.contains("a", ["a", "b", "c"])
+        Assert.contains("dog", {"dog": "poodle", "cat": "siamese", "horse": "arabian"})
 
-    def test_that_items_dont_contain_something(self):
+    def test_that_string_does_not_contain_letter(self):
         try:
             Assert.contains("a", "cde")
         except AssertionError as e:
             pass
+
+    def test_that_list_does_not_contain_element_failure_no_message(self):
         try:
             Assert.contains("d", ["a", "b", "c"])
         except AssertionError as e:
-            pass
+            Assert.equal(e.msg, "d is not found in ['a', 'b', 'c']. ")
+
+    def test_dict_does_not_contain_key_failure_with_message(self):
+        try:
+            Assert.contains("dog", {"cat": "siamese", "horse": "arabian"},
+                            msg="failure message")
+        except AssertionError as e:
+            Assert.equal(e.msg,
+                         "dog is not found in {'horse': 'arabian', 'cat': 'siamese'}. failure message")
 
     def test_less_success(self):
         Assert.less("1", "2")
@@ -172,13 +207,13 @@ class TestNewAsserts:
         try:
             Assert.less("2", "1")
         except AssertionError, e:
-            pass 
+            pass
 
     def test_less_fail_int(self):
         try:
             Assert.less(2, 1)
         except AssertionError, e:
-            pass 
+            pass
 
     def test_less_fail_string_message(self):
         try:
@@ -206,7 +241,7 @@ class TestNewAsserts:
         try:
             Assert.greater(1, 2)
         except AssertionError, e:
-           pass 
+            pass
 
     def test_greater_fail_string_message(self):
         try:
@@ -218,7 +253,7 @@ class TestNewAsserts:
         try:
             Assert.greater(1, 2, "message")
         except AssertionError, e:
-           pass 
+            pass
 
     def test_greater_equal_success(self):
         Assert.greater_equal("2", "1")
@@ -230,7 +265,7 @@ class TestNewAsserts:
         try:
             Assert.greater_equal("1", "2")
         except AssertionError, e:
-            pass 
+            pass
 
     def test_greater_equal_fail_int(self):
         try:
@@ -248,7 +283,7 @@ class TestNewAsserts:
         try:
             Assert.greater_equal(1, 2, "message")
         except AssertionError, e:
-            pass 
+            pass
 
     def test_less_equal_success(self):
         Assert.less_equal("1", "2")
@@ -260,7 +295,7 @@ class TestNewAsserts:
         try:
             Assert.less_equal("2", "1")
         except AssertionError, e:
-            pass 
+            pass
 
     def test_less_equal_fail_int(self):
         try:
@@ -272,7 +307,7 @@ class TestNewAsserts:
         try:
             Assert.less_equal("2", "1", "message")
         except AssertionError, e:
-            pass 
+            pass
 
     def test_less_equal_fail_int_message(self):
         try:
@@ -280,6 +315,16 @@ class TestNewAsserts:
         except AssertionError, e:
             pass
 
+    def test_endswith_success(self):
+        Assert.endswith("abcde", "de")
+        Assert.endswith("abcde", "abcde")
+
+    def test_endswith_fail(self):
+        try:
+            Assert.endswith("abcde", "abc")
+        except AssertionError, e:
+            pass
+
     def _divide_by_zero(self):
         return 1 / 0
 
